@@ -15,10 +15,16 @@ class Composer(models.Model):
         verbose_name = "core_composer_app"
         default_permissions = ()
         permissions = (
-            (rights.COMPOSER_ACCESS, get_formatted_name(rights.COMPOSER_ACCESS)),
+            (
+                rights.COMPOSER_ACCESS,
+                get_formatted_name(rights.COMPOSER_ACCESS),
+            ),
             (
                 rights.COMPOSER_SAVE_TEMPLATE,
                 get_formatted_name(rights.COMPOSER_SAVE_TEMPLATE),
             ),
-            (rights.COMPOSER_SAVE_TYPE, get_formatted_name(rights.COMPOSER_SAVE_TYPE)),
+            (
+                rights.COMPOSER_SAVE_TYPE,
+                get_formatted_name(rights.COMPOSER_SAVE_TYPE),
+            ),
         )
