@@ -3,7 +3,7 @@
 from unittest.case import TestCase
 
 from django.test import override_settings
-from mock.mock import Mock, patch
+from unittest.mock import Mock, patch
 
 from core_main_app.commons import exceptions
 from core_main_app.commons.exceptions import ModelError
@@ -101,7 +101,9 @@ class TestTypeUpsert(TestCase):
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     @patch.object(Type, "dependencies")
     @patch.object(Type, "save")
-    def test_type_upsert_valid_returns_type(self, mock_save, mock_dependencies):
+    def test_type_upsert_valid_returns_type(
+        self, mock_save, mock_dependencies
+    ):
         """test_type_upsert_valid_returns_type"""
 
         mock_user = create_mock_user("1", is_superuser=True)
